from zarnitsa.DataAugmenter import AbstractDataAugmenter

from zarnitsa.nlp.DataAugmenterNLP import DataAugmenterNLP
from zarnitsa.stats.DataAugmenterInternally import DataAugmenterInternally
from zarnitsa.stats.DataAugmenterExternally import DataAugmenterExternally
from zarnitsa.series.DataAugmenterTimeSeries import DataAugmenterTimeSeries
